"Small package for De:code functions under development"

from setuptools import setup

setup(name = 'defunc',
      description = __doc__,
      version = '2018.10.30.3',
      author = 'DESHIMA software team',
      author_email = 'taniguchi@a.phys.nagoya-u.ac.jp',
      url = 'https://github.com/deshima-dev/defunc')